package com.fs.project.service;

import java.util.List;
import com.fs.project.domain.ProjectSettings;

/**
 * 项目设置Service接口
 * 
 * @author fs
 * @date 2026-01-12
 */
public interface IProjectSettingsService 
{
    /**
     * 查询项目设置
     * 
     * @param id 项目设置主键
     * @return 项目设置
     */
    public ProjectSettings selectProjectSettingsById(Long id);

    /**
     * 查询项目设置列表
     * 
     * @param projectSettings 项目设置
     * @return 项目设置集合
     */
    public List<ProjectSettings> selectProjectSettingsList(ProjectSettings projectSettings);

    /**
     * 查询指定公司下的项目设置列表
     *
     * @param companyId 公司ID
     * @return 项目设置集合
     */
    public List<ProjectSettings> selectProjectSettingsByCompanyId(String companyId);

    /**
     * 新增项目设置
     * 
     * @param projectSettings 项目设置
     * @return 结果
     */
    public int insertProjectSettings(ProjectSettings projectSettings);

    /**
     * 修改项目设置
     * 
     * @param projectSettings 项目设置
     * @return 结果
     */
    public int updateProjectSettings(ProjectSettings projectSettings);

    /**
     * 批量删除项目设置
     * 
     * @param ids 需要删除的项目设置主键集合
     * @return 结果
     */
    public int deleteProjectSettingsByIds(Long[] ids);

    /**
     * 删除项目设置信息
     * 
     * @param id 项目设置主键
     * @return 结果
     */
    public int deleteProjectSettingsById(Long id);
}
